#pragma once
#include <vector>
#include "body.h"
#include "vector3.h"
#include "matrix4x4.h"
#include "sbre/sbre.h"

class ObjMesh;

class ModelBody: public Body {
public:
  ModelBody(void);
  virtual ~ModelBody(void);
  void SetPosition(vector3d p);
  /* Not valid to do SetVelocity on these. They are for huge things like
   * space stations and will be static relative to their frame of reference.
   */
  void SetVelocity(vector3d v);
  vector3d GetPosition(void);
  void TransformToModelCoords(const Frame* camFrame);
  void TransformCameraTo(void);
  void ViewingRotation(void);
  void GetRotMatrix(matrix4x4d& m);
  virtual void SetFrame(Frame* f);
  void GeomsSetBody(dBodyID body);
  /* To remove from simulation for a period. */
  virtual void Disable(void);
  virtual void Enable(void);

  void TriMeshUpdateLastPos(void);
  void SetGeomFromSBREModel(int sbreModel, ObjParams* params);

  void RenderSbreModel(const Frame* camFrame, int model, ObjParams* params);
  
  class Geom : public Object {
  public:
    virtual Type GetType(void) { return Object::GEOM; }
    Body* parent;
    int flags;
  };
private:
  std::vector<Geom> geomColl;
  std::vector<dGeomID> geoms;
  dReal triMeshTrans[32];
  int triMeshLastMatrixIndex;
};

